@@ -13,7 +13,7 @@ DEFAULTS = {
     'DEFAULT_REGISTER_SERIALIZER': 'revauth.serializers.RegisterSerializer',
     'DEFAULT_VALIDATION_ISSUER': 'register',
     'GOOGLE_CLIENT_ID': '782455260604-925fnvgriavsgqs89edlecqcgfee8d49.apps.googleusercontent.com',
-    'APPLE_CLIENT_ID': 'fake'
+    'APPLE_CLIENT_ID': 'fake',
 }
 # List of settings that may be in string import notation.
 IMPORT_STRINGS = [
